// 题目混入
import QuestionBase from './QuestionBase.vue';
import RichText from '@/components/common/RichText.vue';
import AudioPlay from '@/views/exercise_questions/create/components/common/AudioPlay.vue';

import { GetQuestionInfo, SaveQuestion } from '@/api/exercise';
import {
  stemTypeList,
  scoreTypeList,
  switchOption,
  isEnable,
  questionNumberTypeList,
  computedQuestionNumber,
} from '@/views/exercise_questions/data/common';

const mixin = {
  data() {
    return {
      stemTypeList,
      scoreTypeList,
      switchOption,
      isEnable,
      questionNumberTypeList,
      computedQuestionNumber,
    };
  },
  provide: ['refreshPreviewData'],
  props: {
    questionId: {
      type: String,
      default: '',
    },
    isChild: {
      type: Boolean,
      default: false,
    },
    isChange: {
      type: Boolean,
      default: false,
    },
  },
  components: {
    QuestionBase,
    RichText,
    AudioPlay,
  },
  created() {
    // 题目的子题目保存
    if (this.isChild) {
      this.$bus.$on('saveQuestion', () => {
        SaveQuestion({
          question_id: this.questionId,
          type: this.data.type,
          additional_type: this.data.property.select_type || '',
          content: JSON.stringify(this.data),
        }).catch(() => {});
      });

      if (this.isChange) return;
      GetQuestionInfo({ question_id: this.questionId })
        .then(({ question }) => {
          if (!question.content) return;
          this.data = JSON.parse(question.content);
          this.refreshPreviewData();
        })
        .catch(() => {});
    }
  },
  watch: {
    'data.property.score'(val) {
      this.data.answer.score = val;
    },
    'data.property.score_type'(val) {
      this.data.answer.score_type = val;
    },
    data: {
      handler() {
        if (!this.isChild) return;
        this.$emit('updatePreviewData', this.data);
      },
      deep: true,
      immediate: true,
    },
  },
  methods: {
    upload(file_id) {
      this.data.file_id_list.push(file_id);
    },
    deleteFile(file_id) {
      let index = this.data.file_id_list.indexOf(file_id);
      if (index !== -1) {
        this.data.file_id_list.splice(index, 1);
      }
    },
    /**
     * 设置题目内容
     * @param {object} param
     * @param {string} param.content 题目内容
     */
    setQuestion({ content }) {
      this.data = JSON.parse(content);
    },
    /**
     * 删除选项
     * @param {Number} i 索引
     */
    deleteOption(i) {
      this.data.option_list.splice(i, 1);
    },
  },
};

export default mixin;
